<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Über …</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="53"/>
        <location filename="../about.ui" line="109"/>
        <location filename="../about.ui" line="165"/>
        <source>icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Übersetzer</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1-Browser für den SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Based on UMPlayer</source>
        <translation>Basierend auf dem UMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Bewegliche Version</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Kompiliert mit Qt %1 (durch %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our web for updates:</source>
        <translation>Webseite für Aktualisierungen besuchen:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="98"/>
        <source>Spanish</source>
        <translation>Spanisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="115"/>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="108"/>
        <source>Lithuanian</source>
        <translation>Litauisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="102"/>
        <source>Japanese</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>Basque</source>
        <translation>Baskisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="104"/>
        <source>Portuguese</source>
        <translation>Portugiesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="119"/>
        <source>Hungarian</source>
        <translation>Ungarisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="114"/>
        <source>Polish</source>
        <translation>Polnisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="111"/>
        <source>Hebrew</source>
        <translation>Hebräisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="106"/>
        <source>Ukrainian</source>
        <translation>Ukrainisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="125"/>
        <source>Norwegian Nynorsk</source>
        <translation>Norwegisch (Neunorwegisch)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="101"/>
        <source>Czech</source>
        <translation>Tschechisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="92"/>
        <source>Many people contributed with translations.</source>
        <translation>Viele Leute haben mit Übersetzungen beigetragen.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="93"/>
        <source>You can also help to translate SMPlayer into your own language.</source>
        <translation>Sie können auch mithelfen, den SMPlayer in Ihre eigene Sprache zu übersetzen.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Besuchen Sie %1 und treten Sie einem Übersetzungsteam bei.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="96"/>
        <source>Current translators from the transifex teams:</source>
        <translation>Aktuelle Übersetzer aus den Transifex-Mannschaften:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="103"/>
        <source>Korean</source>
        <translation>Koreanisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="109"/>
        <source>Malay</source>
        <translation>Malaiisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="110"/>
        <source>Portuguese - Brazil</source>
        <translation>Portugiesisch (Brasilien)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="112"/>
        <source>Simplified Chinese</source>
        <translation>Vereinfachtes Chinesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="116"/>
        <source>French</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="118"/>
        <source>Danish</source>
        <translation>Dänisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="122"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="123"/>
        <source>Traditional Chinese</source>
        <translation>Traditionelles Chinesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="126"/>
        <source>Swedish</source>
        <translation>Schwedisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="120"/>
        <source>Turkish</source>
        <translation>Türkisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="121"/>
        <source>Finnish</source>
        <translation>Finnisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="127"/>
        <source>Arabic</source>
        <translation>Arabisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="128"/>
        <source>Georgian</source>
        <translation>Georgisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="105"/>
        <source>Serbian</source>
        <translation>Serbisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="100"/>
        <source>Croatian</source>
        <translation>Kroatisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="124"/>
        <source>Bulgarian</source>
        <translation>Bulgarisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="113"/>
        <source>Vietnamese</source>
        <translation>Vietnamesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>Indonesian</source>
        <translation>Indonesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="129"/>
        <source>Arabic - Saudi Arabia</source>
        <translation>Arabisch (Saudi-Arabien)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="130"/>
        <source>Sinhala</source>
        <translation>Singhalesisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="131"/>
        <source>Greek</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="132"/>
        <source>Estonian</source>
        <translation>Estnisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="133"/>
        <source>N&apos;ko</source>
        <translation>N&apos;ko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="134"/>
        <source>Italian</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="135"/>
        <source>Uzbek</source>
        <translation>Usbekisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="136"/>
        <source>Catalan</source>
        <translation>Katalanisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="137"/>
        <source>Slovak</source>
        <translation>Slowakisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="138"/>
        <source>British English</source>
        <translation>Britisches Englisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="139"/>
        <source>Albanian</source>
        <translation>Albanisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="140"/>
        <source>Dutch</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="141"/>
        <source>Romanian</source>
        <translation>Rumänisch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="142"/>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="143"/>
        <source>Telugu</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="144"/>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="145"/>
        <source>Malayalam</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="170"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="107"/>
        <source>Galician</source>
        <translation>Galizisch</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="37"/>
        <source>Downloading...</source>
        <translation>Herunterladen …</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="58"/>
        <source>Connecting to %1</source>
        <translation>Mit %1 verbinden</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="126"/>
        <source>The Youtube code has been updated successfully.</source>
        <translation>Der Youtube-Code wurde erfolgreich aktualisiert.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="127"/>
        <source>Installed version: %1</source>
        <translation>Installierte Version: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="128"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <source>An error happened writing %1</source>
        <translation>Ein Fehler trat auf beim Schreiben von %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Ein Fehler trat auf beim Herunterladen der Datei:&lt;br&gt;%1</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>Recording</source>
        <translation>Aufnahme</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="28"/>
        <source>&amp;Save to this folder</source>
        <translation>&amp;In diesem Ordner speichern</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="45"/>
        <source>&amp;Quality</source>
        <translation>&amp;Qualität</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="157"/>
        <source>Standard Feeds</source>
        <translation>Standard-Feeds</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="163"/>
        <source>&amp;Region:</source>
        <translation>&amp;Region:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="189"/>
        <source>Period of &amp;time:</source>
        <translation>&amp;Zeitraum:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="80"/>
        <source>Playback</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="88"/>
        <source>Q&amp;uality:</source>
        <translation>Q&amp;ualität:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="125"/>
        <source>&amp;Player:</source>
        <translation>&amp;Filmwiedergabe:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="40"/>
        <source>All time</source>
        <translation>Jederzeit</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="41"/>
        <source>This month</source>
        <translation>In diesem Monat</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="42"/>
        <source>This week</source>
        <translation>In dieser Woche</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="43"/>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
</context>
<context>
    <name>DownloadFile</name>
    <message>
        <location filename="../downloadfile.cpp" line="117"/>
        <source>%1 hours</source>
        <translation>%1 Stunden</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="123"/>
        <source>%1 minutes</source>
        <translation>%1 Minuten</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="110"/>
        <source>unknown time remaining</source>
        <translation>unbekannte Zeit verbleibend</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="126"/>
        <source>%1 seconds</source>
        <translation>%1 Sekunden</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="127"/>
        <source>%1 remaining</source>
        <translation>%1 verbleibend</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="132"/>
        <source>%1 of %2 MB</source>
        <translation>%1 von %2 MB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="138"/>
        <source>%1 of %2 KB</source>
        <translation>%1 von %2 KB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="144"/>
        <source>%1 of %2 bytes</source>
        <translation>%1 von %2 Bytes</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="148"/>
        <source>%1 of unknown size</source>
        <translation>%1 von unbekannter Größe</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="153"/>
        <source>%1 MB/sec</source>
        <translation>%1 MB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="157"/>
        <source>%1 KB/sec</source>
        <translation>%1 KB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="161"/>
        <source>%1 bytes/sec</source>
        <translation>%1 Bytes/s</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="54"/>
        <source>Click to select a file or folder</source>
        <translation>Zur Auswahl einer Datei oder eines Ordners anklicken</translation>
    </message>
</context>
<context>
    <name>RecordingDelegate</name>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Canceled</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="155"/>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="159"/>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="163"/>
        <source>%1 bytes</source>
        <translation>%1 Bytes</translation>
    </message>
</context>
<context>
    <name>RecordingDialog</name>
    <message>
        <location filename="../recordingdialog.cpp" line="208"/>
        <location filename="../recordingdialog.cpp" line="527"/>
        <source>Recordings</source>
        <translation>Aufnahmen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="209"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Liste leeren</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="210"/>
        <location filename="../recordingdialog.cpp" line="658"/>
        <source>&amp;Open folder</source>
        <translation>&amp;Ordner öffnen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>There was an error in retrieving the download URL.</source>
        <translation>Beim Herunterladen der Download-Adresse ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>Recording failed</source>
        <translation>Aufnahme fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="413"/>
        <location filename="../recordingdialog.cpp" line="795"/>
        <source>Starting</source>
        <translation>Starte</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="448"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="452"/>
        <source>Completed</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message numerus="yes">
        <location filename="../recordingdialog.cpp" line="531"/>
        <source>%1% of %n video - Recordings</source>
        <translation>
            <numerusform>%1% von %n Videoaufnahmen</numerusform>
            <numerusform>%1% von %n Videoaufnahmen</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="616"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="618"/>
        <source>&amp;Remove from list</source>
        <translation>&amp;Aus der Liste entfernen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="639"/>
        <location filename="../recordingdialog.cpp" line="661"/>
        <source>Remove from &amp;list</source>
        <translation>&amp;Aus der Liste entfernen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="635"/>
        <source>&amp;Retry</source>
        <translation>&amp;Wiederholen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="657"/>
        <source>&amp;Play</source>
        <translation>&amp;Wiedergabe</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="660"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="742"/>
        <source>Fetching URL...</source>
        <translation>Adresse abrufen …</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="759"/>
        <source>File error</source>
        <translation>Dateifehler</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="760"/>
        <source>The file does not exists, would you like to remove it from the list?</source>
        <translation>Die Datei existiert nicht, soll sie aus der Liste entfernt werden?</translation>
    </message>
</context>
<context>
    <name>Regions</name>
    <message>
        <location filename="../regions.cpp" line="26"/>
        <source>Argentina</source>
        <translation>Argentinien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="27"/>
        <source>Australia</source>
        <translation>Australien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="29"/>
        <source>Belgium</source>
        <translation>Belgien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="30"/>
        <source>Brazil</source>
        <translation>Brasilien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="31"/>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="32"/>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="33"/>
        <source>Colombia</source>
        <translation>Kolumbien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="34"/>
        <source>Czech Republic</source>
        <translation>Tschechische Republik</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="35"/>
        <source>Egypt</source>
        <translation>Ägypten</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="36"/>
        <source>France</source>
        <translation>Frankreich</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="37"/>
        <source>Germany</source>
        <translation>Deutschland</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="38"/>
        <source>Great Britain</source>
        <translation>Großbritannien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="39"/>
        <source>Hong Kong</source>
        <translation>Hongkong</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="40"/>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="41"/>
        <source>India</source>
        <translation>Indien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="42"/>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="43"/>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="44"/>
        <source>Italy</source>
        <translation>Italien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="45"/>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="46"/>
        <source>Jordan</source>
        <translation>Jordanien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="47"/>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="48"/>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="49"/>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="50"/>
        <source>Netherlands</source>
        <translation>Niederlande</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="51"/>
        <source>New Zealand</source>
        <translation>Neuseeland</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="52"/>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="53"/>
        <source>Philippines</source>
        <translation>Philippinen</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="54"/>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="55"/>
        <source>Russia</source>
        <translation>Russland</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="56"/>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="57"/>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="58"/>
        <source>South Africa</source>
        <translation>Südafrika</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="59"/>
        <source>South Korea</source>
        <translation>Südkorea</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="60"/>
        <source>Spain</source>
        <translation>Spanien</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="61"/>
        <source>Sweden</source>
        <translation>Schweden</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="63"/>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="64"/>
        <source>United Arab Emirates</source>
        <translation>Vereinigte Arabische Emirate</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="65"/>
        <source>United States</source>
        <translation>Vereinigten Staaten von Amerika</translation>
    </message>
</context>
<context>
    <name>YTDelegate</name>
    <message>
        <location filename="../ytdelegate.cpp" line="115"/>
        <source>%L1 views</source>
        <translation>%L1mal angesehen</translation>
    </message>
</context>
<context>
    <name>YTDialog</name>
    <message>
        <location filename="../ytdialog.cpp" line="227"/>
        <source>YouTube Browser - SMPlayer</source>
        <translation>YouTube-Browser - SMPlayer</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="277"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="283"/>
        <source>Information</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="290"/>
        <source>Show recordings</source>
        <translation>Aufnahmen anzeigen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="296"/>
        <source>Enter URL</source>
        <translation>Adresse eingeben</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="497"/>
        <source>Most Relevant</source>
        <translation>Passendste</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="501"/>
        <source>Most Recent</source>
        <translation>Neueste</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="505"/>
        <source>Most Viewed</source>
        <translation>Meist gesehen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="509"/>
        <source>Most Popular</source>
        <translation>Beliebteste</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="535"/>
        <source>Most popular videos on YouTube%1</source>
        <translation>Beliebteste Videos auf YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="656"/>
        <source>Error: Could not connect to Youtube server.</source>
        <translation>Fehler: Konnte nicht zum YouTube-Server verbinden.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="766"/>
        <source>R&amp;ecord audio</source>
        <translation>&amp;Ton aufnehmen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="771"/>
        <source>&amp;Add URL to the SMPlayer playlist</source>
        <translation>&amp;Adresse zur SMPlayer Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="839"/>
        <source>Enter a URL</source>
        <translation>Eine Adresse eingeben</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="963"/>
        <location filename="../ytdialog.cpp" line="974"/>
        <source>Problems with Youtube</source>
        <translation>Probleme mit Youtube</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="965"/>
        <source>Do you want to update the Youtube code? This may fix the problem.</source>
        <translation>Möchten Sie den Youtube-Code aktualisieren? Dies könnte das Problem beheben.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="964"/>
        <location filename="../ytdialog.cpp" line="975"/>
        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation>Aufgrund von Änderungen bei Youtube, kann das Video »%1« leider nicht abgespielt oder aufgezeichnet werden.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="976"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Vielleicht könnte eine Aktualisierung dieser Anwendung das Problem beheben.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="540"/>
        <source>YouTube%2 results for &quot;%1&quot;</source>
        <translation>YouTube%2-Ergebnisse für »%1«</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="513"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="517"/>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="536"/>
        <source>Most popular sport videos on YouTube%1</source>
        <translation>Die beliebtesten Sportvideos auf YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="537"/>
        <source>Most popular music videos on YouTube%1</source>
        <translation>Die beliebtesten Musikvideos auf YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="664"/>
        <source>No videos found</source>
        <translation>Keine Videos gefunden</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="666"/>
        <source>No videos found for &quot;%1&quot;</source>
        <translation>Keine Videos für »%1« gefunden</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="763"/>
        <source>&amp;Play video</source>
        <translation>Video &amp;wiedergeben</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="765"/>
        <source>&amp;Record video</source>
        <translation>Video &amp;aufnehmen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="768"/>
        <source>&amp;Watch on YouTube</source>
        <translation>Auf &amp;YouTube ansehen</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="769"/>
        <source>&amp;Copy link</source>
        <translation>Verweis &amp;kopieren</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="252"/>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="258"/>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="840"/>
        <source>Enter a Youtube URL to record</source>
        <translation>Eine Youtube-Adresse zum Aufnehmen eingeben</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="949"/>
        <location filename="../ytdialog.cpp" line="951"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
</TS>
